@@ -6,7 +6,7 @@
   use Win32::OLE();
   use vars qw($VERSION $drh);
 
-  $VERSION = '2.97';
+  $VERSION = '2.98';
 
   $drh = undef;
 
@@ -27,6 +27,11 @@
   }
 
 
+  sub CLONE {
+    undef $drh;
+  }
+
+
   sub errors {
     my $h = shift;
     my $Cxn = $h->{ado_conn};
@@ -1138,7 +1143,7 @@
         $i->{Size} = $attr->{ado_maxlen};
       }
       else {
-        $i->{Size} = length $value;
+        $i->{Size} = length $value || 1;
       }
       if ( $i->{Type} == $Enums->{DataTypeEnum}{adVarBinary}
         || $i->{Type} == $Enums->{DataTypeEnum}{adLongVarBinary}
@@ -1905,7 +1910,7 @@ dbi-users@perl.org and CC them to me (sgoeldner@cpan.org).
   Copyright (c) 2001, Tim Bunce, Thomas Lowery, Steffen Goeldner
   Copyright (c) 2002, Thomas Lowery, Steffen Goeldner
   Copyright (c) 2003, Thomas Lowery, Steffen Goeldner
-  Copyright (c) 2004-2009 Steffen Goeldner
+  Copyright (c) 2004-2011 Steffen Goeldner
 
   All rights reserved.
 
